@@ -1,5 +1,6 @@
 from ..base import ShopifyResource
 
+
 class Metafield(ShopifyResource):
     _prefix_source = "/admin/$resource/$resource_id/"
 
@@ -9,4 +10,4 @@ class Metafield(ShopifyResource):
         if resource:
             return "/admin/%s/%s" % (resource, options["resource_id"])
         else:
-            return "/admin/"
+            return "/admin"
